@@ -1,11 +1,10 @@
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError
 
-from command_handler.command.handler import registry
 from command_handler.request.validator.exceptions import AssertionFailedException
 
 
-def command(request):
+def command(request, registry):
     body = request.get_json()
     try:
         assert all(k in body for k in ("payload", "command")), "Either `payload` or `command` field is missing"
