@@ -18,7 +18,8 @@ class Invoker(MethodView):
             if a not in asserts:
                 asserts.append(a)
 
-        self.validator = ValidatorFactory.create(asserts)
+        self.registry = registry
+        self.validator = ValidatorFactory.create(registry, asserts)
 
     def post(self, *args, **kwargs):
         response = {}
@@ -36,7 +37,7 @@ class Invoker(MethodView):
                 return response, 400, headers
 
             command = data["command"]
-            handler = registry[command][0]
+            handler = self.registry[command][0]
 
             payload = data["payload"]
             command = data["command"]
